supportsRelationJoins property
Whether the database supports relation joins (if false, relations are fetched separately and joined in-memory)
Implementation
final bool supportsRelationJoins;
Whether the database supports relation joins (if false, relations are fetched separately and joined in-memory)
final bool supportsRelationJoins;