QueryErrorEvent class

Event data for a failed query.

Constructors

QueryErrorEvent({required String sql, required List parameters, String? model, String? operation, required Duration duration, required Object error, StackTrace? stackTrace})
const

Properties

duration → Duration
How long before the error occurred
final
error → Object
The error that occurred
final
hashCode → int
The hash code for this object.
no setterinherited
model → String?
Name of the model being queried (if known)
final
operation → String?
Type of operation (findMany, create, update, etc.)
final
parameters → List
Parameters that were bound to the query
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql → String
The SQL query that failed
final
stackTrace → StackTrace?
Stack trace (if available)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited