QueryMetric class

A single query execution metric.

Constructors

QueryMetric({required String sql, String? operation, required Duration duration, required int rowCount, required bool success, String? error, required DateTime timestamp})
const

Properties

duration → Duration
final
error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
operation → String?
final
rowCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql → String
final
success → bool
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited