ResultSetConverter mixin

Mixin providing common result set conversion utilities.

This mixin extracts shared logic used by both QueryExecutor and TransactionExecutor to convert database results to Dart types.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deserializeValue(dynamic value, ColumnType type) → dynamic
Deserialize a database value to Dart type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resultSetToMaps(SqlResultSet result, {bool preserveAliases = false}) List<Map<String, dynamic>>
Convert SqlResultSet to list of maps.
snakeToCamelCase(String input) String
Convert snake_case to camelCase.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited