includeParameters property
Whether to attach bound parameters to the Sentry event. Off by default because parameters may contain PII / secrets.
Implementation
final bool includeParameters;
Whether to attach bound parameters to the Sentry event. Off by default because parameters may contain PII / secrets.
final bool includeParameters;