SqlQueryable class abstract

Interface for executing SQL queries (implemented by adapters and transactions).

Implementers

Constructors

SqlQueryable()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeRaw(SqlQuery query) → Future<int>
Execute a command and return affected row count
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryRaw(SqlQuery query) → Future<SqlResultSet>
Execute a query and return results
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited