Transaction class abstract

Abstract interface for database transactions.

Implementers

Constructors

Transaction()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
Whether the transaction is still active
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

commit() → Future<void>
Commit the transaction
executeRaw(SqlQuery query) → Future<int>
Execute a command within the transaction (returns affected rows)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryRaw(SqlQuery query) → Future<SqlResultSet>
Execute a query within the transaction
rollback() → Future<void>
Rollback the transaction
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited