SqlCompiler class
Compiles JSON queries to SQL.
Constructors
- SqlCompiler({required String provider, String? schemaName, SchemaRegistry? schema, bool? strictModelValidation})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- provider → String
-
final
- relationCompiler → RelationCompiler
-
Get or create relation compiler.
Uses startingCounter: 1 since t0 is reserved for the base table.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → SchemaRegistry?
-
final
- schemaName → String?
-
final
Methods
-
buildRelationMutationsFromResult(
JsonQuery query, Map< String, dynamic> ? resultRow) → List<SqlQuery> -
Rebuild relation mutations using the parent id from the main mutation's
RETURNING row — this fixes nested writes on a create whose PK is
DB-generated (
@default(uuid())), where the id isn't known at compile. -
compile(
JsonQuery query) → SqlQuery - Compile a JSON query to SQL.
-
compileWithRelations(
JsonQuery query) → CompiledMutation - Compile a mutation query with potential relation operations.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- strictModelValidation ↔ bool
-
Enable strict model name validation.
getter/setter pair